@@ -1,7 +1,7 @@
 /*
  This file is part of MOST.
 
- Copyright (c) 1991, 1999, 2002 John E. Davis
+ Copyright (c) 1991, 1999, 2002, 2005 John E. Davis
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -171,8 +171,18 @@ static int most_analyse_line(unsigned char *begg, unsigned char *endd,
 	     /* drop */
 	  }
 	
-	if (((ch >= ' ') && (ch < 0x7F))
-	    || (ch >= SLsmg_Display_Eight_Bit))
+	if ((ch >= ' ') && (ch < 0x7F))
+	  {
+	     if ((i >= min_col) && (i < max_col))
+	       {
+		  out[i-min_col] = ch;
+		  attributes[i-min_col] = attr;
+	       }
+	     i++;
+	     continue;
+	  }
+	
+	if (ch >= SLsmg_Display_Eight_Bit)
 	  {
 	     if ((i >= min_col) && (i < max_col))
 	       {
@@ -341,13 +351,16 @@ void most_display_line (void)
 	output_binary_formatted_line ();
 	return;
      }
-
-   if (line_len < SLtt_Screen_Cols + 1)
+#if SLANG_VERSION < 20000
+# define SLUTF8_MAX_MBLEN	1
+#endif
+   if (line_len < (unsigned int)(SLtt_Screen_Cols + 1) * SLUTF8_MAX_MBLEN)
      {
 	SLfree ((char *) line);
 	SLfree ((char *) attr);
 	
-	line_len = SLtt_Screen_Cols + 1;
+	line_len = (SLtt_Screen_Cols + 1) * SLUTF8_MAX_MBLEN;
+	
 	if ((NULL == (line = (unsigned char *) SLmalloc (line_len)))
 	    || (NULL == (attr = (unsigned char *) SLmalloc (line_len))))
 	  most_exit_error ("Out of memory");
