@@ -2,7 +2,7 @@
 /*
  This file is part of MOST.
 
- Copyright (c) 1991, 1999, 2002 John E. Davis
+ Copyright (c) 1991, 1999, 2002, 2005 John E. Davis
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -22,6 +22,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <slang.h>
 
 #include "most.h"
 #include "window.h"
@@ -39,7 +40,6 @@ int Most_Case_Sensitive = 0;
 char Most_Search_Str[256];
 int Most_Search_Dir = 1;
 
-#include <slang.h>
 #include "jdmacros.h"
 
 #define UPCASE(ch) ((!Most_Case_Sensitive && (ch <= 'z') && (ch >= 'a')) ? (ch - 32) : ch)
@@ -59,10 +59,13 @@ static struct regexp	*regpattern = NULL;
 # else
 
 /* slang regular expression structure */
+#if SLANG_VERSION < 20000
 static SLRegexp_Type	regdata;
-
 /* buffer for compiled regular expression */
 static unsigned char regbuf[sizeof(Most_Search_Str) * 3];
+#else
+static SLRegexp_Type *Regexp;
+#endif
 # endif	/* HAVE_V8_REGCOMP */
 
 /* set if regexp compiled OK, 0 if regular expression error */
@@ -98,7 +101,6 @@ static int do_regcomp(unsigned char *key)
    unsigned char UpCaseKey[sizeof(savepattern)];
 # ifndef HAVE_V8_REGCOMP
    int	posn;			/* reg exp error at this offset */
-   char	string[128];		/* reg exp error string */
 # endif
 
    /*
@@ -151,23 +153,32 @@ static int do_regcomp(unsigned char *key)
      }
 # else
 
+#  if SLANG_VERSION < 20000
    regdata.case_sensitive = 1;
    regdata.buf = regbuf;
    regdata.pat = Most_Case_Sensitive ? key : UpCaseKey;
    regdata.buf_len = sizeof (regbuf);
    posn = SLang_regexp_compile(&regdata);
+#  else
+   if (Regexp != NULL)
+     SLregexp_free (Regexp);
+   if (NULL == (Regexp = SLregexp_compile ((char *)key, Most_Case_Sensitive ? 0 : SLREGEXP_CASELESS)))
+     posn = -1;
+   else
+     posn = 0;
+#  endif
+
    if (posn == 0)
      {
 	regcompOK = 1;
 	return 1;
      }
-
-   sprintf(string, "error detected %d chars into expression", posn);
-   regerror(string);
+   regerror ("Unable to compile pattern");
 # endif	/* HAVE_V8_REGCOMP */
-	/*
-	 * regcomp has already printed error message via regerror().
-	 */
+
+   /*
+    * regcomp has already printed error message via regerror().
+    */
    savepattern[0] = '\0';
    return 0;				/* failure */
 }
@@ -184,7 +195,11 @@ static unsigned char *do_regexec(unsigned char *string)
    else
      return( NULL );
 # else
+#  if SLANG_VERSION < 20000
    return ( SLang_regexp_match(string, strlen((char *)string), &regdata) );
+#  else
+   return (unsigned char *)SLregexp_match (Regexp, (char *)string, strlen ((char *)string));
+#  endif
 # endif	/* HAVE_V8_REGCOMP */
 }
 
@@ -330,8 +345,13 @@ static unsigned char *forw_search_region(unsigned char *beg,
 	 * must be beyond the start of the window), must be a "\n",
 	 * otherwise do_regexec() isn't called.
 	 */
-	if ( ((*key != '^') || (linebeg > Most_Win->beg_pos && linebeg[-1] == '\n'))
-	    && (match = do_regexec(Most_Case_Sensitive ? linebeg : copy)) )
+	if ( 
+# if 0
+	     ((*key != '^') 
+	      || (linebeg > Most_Win->beg_pos && linebeg[-1] == '\n'))
+	     &&
+#endif
+	     (match = do_regexec(Most_Case_Sensitive ? linebeg : copy)))
 	  {
 	     *p = '\n';
 	     if ( Most_Case_Sensitive == 0 )
